"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const config = require("config");
const Authentication_1 = require("../Authentication");
const AuthenticationRequest_1 = require("../AuthenticationRequest");
const RefreshRequest_1 = require("../RefreshRequest");
const AuthCache_1 = require("../AuthCache");
const TriggerEmailMessage_1 = require("../../send/TriggerEmailMessage");
const TriggerEmailMessageRequest_1 = require("../../send/TriggerEmailMessageRequest");
const Recipient_1 = require("../../send/Recipient");
const queryString = require("querystring");
const RecipientData_1 = require("../../send/RecipientData");
const AuthConfig_1 = require("../AuthConfig");
const nock_utils_1 = require("nock-utils");
/**
 * In order to re-generate the cassette, just delete the
 * @constant CASSETTE_PATH file and set real username and passwords.
 */
const CASSETTE_PATH = `${__dirname}/cassettes/responsysAuth.json`;
const CAMPAIGN = config.get('campaign');
const WRONG_PASSWORD = 'wrong_password';
const ERROR_WRONG_PASSWORD = 'INVALID_USER_NAME_PASSWORD';
const recorder = new nock_utils_1.HttpRecorder(CASSETTE_PATH);
describe('Authentication', () => {
    const authCache = new AuthCache_1.AuthCache();
    before(() => {
        authCache.clear();
        recorder.start();
    });
    after(() => {
        authCache.clear();
        recorder.stop();
    });
    it('should automatically refresh an expired token', (done) => {
        authCache.set({
            authToken: config.get('refresh.authToken'),
            issuedAt: config.get('refresh.issuedAt'),
            endPoint: config.get('refresh.endPoint')
        });
        const recipient1 = new Recipient_1.Recipient();
        recipient1.emailAddress = 'dev@comparaonline.com';
        recipient1.emailFormat = 'HTML_FORMAT';
        recipient1.mobileNumber = '951349394';
        const campaignUnescaped = queryString.escape(CAMPAIGN);
        const recipients = new Set();
        recipients.add(new RecipientData_1.RecipientData(recipient1));
        const triggerEmailRequest = new TriggerEmailMessageRequest_1.TriggerEmailMessageRequest(recipients, campaignUnescaped);
        const triggerEmailClient = new TriggerEmailMessage_1.TriggerEmailMessage();
        triggerEmailClient.send(triggerEmailRequest).then((result) => {
            chai_1.expect(result.status.code).to.equal(200);
            done();
        });
    });
    it('should authenticate a user and return token and endpoint', (done) => {
        const auth = new Authentication_1.Authentication();
        const authRequest = new AuthenticationRequest_1.AuthenticationRequest();
        auth.signin(authRequest).then((result) => {
            chai_1.expect(result.status.code).to.equal(200);
            const entity = JSON.parse(result.entity);
            chai_1.expect(entity.authToken).to.be.a('string');
            chai_1.expect(entity.issuedAt).to.be.a('number');
            chai_1.expect(entity.endPoint).to.be.a('string');
            done();
        });
    });
    it('should throw an error with incorrect credentials', (done) => {
        AuthConfig_1.AuthConfig.password = WRONG_PASSWORD;
        const auth = new Authentication_1.Authentication();
        const authRequest = new AuthenticationRequest_1.AuthenticationRequest();
        auth.signin(authRequest).then((result) => {
            chai_1.expect(result.status.code).to.equal(400);
            const errorResult = JSON.parse(result.entity);
            chai_1.expect(errorResult.errorCode).to.equal(ERROR_WRONG_PASSWORD);
            AuthConfig_1.AuthConfig.init();
            done();
        });
    });
    it('should take a valid token and refresh it', (done) => {
        const auth = new Authentication_1.Authentication();
        const authRequest = new AuthenticationRequest_1.AuthenticationRequest();
        auth.signin(authRequest).then(() => {
            const refreshRequest = new RefreshRequest_1.RefreshRequest();
            auth.refresh(refreshRequest).then((result) => {
                const refreshResult = JSON.parse(result.entity);
                chai_1.expect(refreshResult.authToken).to.be.a('string');
                chai_1.expect(refreshResult.issuedAt).to.be.a('number');
                chai_1.expect(refreshResult.endPoint).to.be.a('string');
                done();
            });
        });
    });
    it('should not invalidate the previous token after refreshing', async () => {
        const auth = new Authentication_1.Authentication();
        const authRequest = new AuthenticationRequest_1.AuthenticationRequest();
        const authResult = await auth.signin(authRequest);
        const signinResult = JSON.parse(authResult.entity);
        const originalToken = signinResult.authToken;
        const firstRefresh = new RefreshRequest_1.RefreshRequest(originalToken);
        await auth.refresh(firstRefresh);
        const secondRefresh = new RefreshRequest_1.RefreshRequest(originalToken);
        const secondRefreshResult = await auth.refresh(secondRefresh);
        const secondRefreshEntity = JSON.parse(secondRefreshResult.entity);
        chai_1.expect(secondRefreshEntity.authToken).to.be.a('string');
        chai_1.expect(secondRefreshEntity.issuedAt).to.be.a('number');
        chai_1.expect(secondRefreshEntity.endPoint).to.be.a('string');
    });
});
//# sourceMappingURL=Authentication.test.js.map