"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const TriggerEmailMessage_1 = require("../TriggerEmailMessage");
const Recipient_1 = require("../Recipient");
const TriggerEmailMessageRequest_1 = require("../TriggerEmailMessageRequest");
const queryString = require("querystring");
const RecipientData_1 = require("../RecipientData");
const AuthCache_1 = require("../../auth/AuthCache");
const nock_utils_1 = require("nock-utils");
const OptionalData_1 = require("../OptionalData");
const ListName_1 = require("../ListName");
const CAMPAIGN = 'test';
const CASSETTE_PATH = `${__dirname}/cassettes/triggerEmailMessageCassette.json`;
const recorder = new nock_utils_1.HttpRecorder(CASSETTE_PATH);
describe('TriggerEmailMessage', () => {
    const campaign = queryString.escape(CAMPAIGN);
    const authCache = new AuthCache_1.AuthCache();
    before(() => {
        authCache.clear();
        recorder.start();
    });
    after(() => {
        authCache.clear();
        recorder.stop();
    });
    it('should send an email', async () => {
        const recipients = new Set();
        const recipient1 = new Recipient_1.Recipient();
        recipient1.emailAddress = 'tsuarez@comparaonline.com';
        recipient1.emailFormat = 'HTML_FORMAT';
        recipient1.mobileNumber = '951349394';
        const optionalData1 = new OptionalData_1.OptionalData('FIST_NAME', 'name');
        const optionalData2 = new OptionalData_1.OptionalData('LAST_NAME', 'last name');
        const optionalData = new Set();
        optionalData.add(optionalData1);
        optionalData.add(optionalData2);
        const data = new RecipientData_1.RecipientData(recipient1, optionalData);
        recipients.add(data);
        const campaign = queryString.escape(CAMPAIGN);
        const message = new TriggerEmailMessageRequest_1.TriggerEmailMessageRequest(recipients, campaign);
        const trigger = new TriggerEmailMessage_1.TriggerEmailMessage();
        const result = await trigger.send(message);
        const resultArray = JSON.parse(result.entity);
        chai_1.expect(result.status.code).to.equal(200);
        resultArray.forEach((element) => {
            chai_1.expect(element.errorMessage).to.be.null;
            chai_1.expect(element.success).to.be.true;
            chai_1.expect(element.recipientId).to.be.gt(0);
        });
    });
    it('should send an email with listName', async () => {
        const recipients = new Set();
        const recipient1 = new Recipient_1.Recipient();
        recipient1.emailAddress = 'tsuarez@comparaonline.com';
        recipient1.emailFormat = 'HTML_FORMAT';
        recipient1.mobileNumber = '951349394';
        const listName = new ListName_1.ListName();
        listName.objectName = 'CONTACTS_LIST';
        listName.folderName = 'CONTACTS_LIST';
        recipient1.listName = listName;
        const optionalData1 = new OptionalData_1.OptionalData('FIST_NAME', 'name');
        const optionalData2 = new OptionalData_1.OptionalData('LAST_NAME', 'last name');
        const optionalData = new Set();
        optionalData.add(optionalData1);
        optionalData.add(optionalData2);
        const data = new RecipientData_1.RecipientData(recipient1, optionalData);
        recipients.add(data);
        const campaign = queryString.escape(CAMPAIGN);
        const message = new TriggerEmailMessageRequest_1.TriggerEmailMessageRequest(recipients, campaign);
        const trigger = new TriggerEmailMessage_1.TriggerEmailMessage();
        const result = await trigger.send(message);
        const resultArray = JSON.parse(result.entity);
        chai_1.expect(result.status.code).to.equal(200);
        resultArray.forEach((element) => {
            chai_1.expect(element.errorMessage).to.be.null;
            chai_1.expect(element.success).to.be.true;
            chai_1.expect(element.recipientId).to.be.gt(0);
        });
    });
    it('should return NO_RECIPIENT_FOUND error for a non existing email address', async () => {
        const recipients = new Set();
        const recipient1 = new Recipient_1.Recipient();
        recipient1.emailAddress = 'emailtest@comparaonline.com';
        const data = new RecipientData_1.RecipientData(recipient1);
        recipients.add(data);
        const trigger = new TriggerEmailMessage_1.TriggerEmailMessage();
        const message = new TriggerEmailMessageRequest_1.TriggerEmailMessageRequest(recipients, campaign);
        const result = await trigger.send(message);
        const results = JSON.parse(result.entity);
        chai_1.expect(results).to.have.lengthOf(1);
        const error = results[0];
        chai_1.expect(error.success).to.be.false;
        chai_1.expect(error.recipientId).to.equal(-1);
        chai_1.expect(error.errorMessage).to.contain('NO_RECIPIENT_FOUND');
    });
    it('should return RECIPIENT_STATUS_UNDELIVERABLE error for wrong email address', async () => {
        const recipients = new Set();
        const recipient = new Recipient_1.Recipient();
        recipient.customerId = '5634169';
        recipient.emailAddress = 'hola@comparaonline.com';
        const data = new RecipientData_1.RecipientData(recipient);
        recipients.add(data);
        const trigger = new TriggerEmailMessage_1.TriggerEmailMessage();
        const message = new TriggerEmailMessageRequest_1.TriggerEmailMessageRequest(recipients, campaign);
        const result = await trigger.send(message);
        const results = JSON.parse(result.entity);
        chai_1.expect(results).to.have.lengthOf(1);
        const error = results[0];
        chai_1.expect(error.success).to.be.false;
        chai_1.expect(error.recipientId).to.equal(-1);
        chai_1.expect(error.errorMessage).to.contain('RECIPIENT_STATUS_UNDELIVERABLE');
    });
});
//# sourceMappingURL=TriggerEmailMessage.test.js.map